@@ -29,13 +29,16 @@ from datascientists.core.hypothesisTesting import *
 # module level doc-string
 __doc__ = f"""
 NAME
-    datascientists - https://zacks.one
+    datascientists - https://pypi.org/project/datascientists/
 
 AUTHOR
     Zacks Shen
 
 DESCRIPTION
-    Quick Data Science tools.
+    Quick Data Science tools, providing data processing and visualization in Hypotheses Testing, Regression, and etc.
+
+README
+    https://pypi.org/project/datascientists/
 
 DEPENDICES
     numpy
